Please use the temporary password below to sign in to console and reset it.

Hi {{user_name}}, We noticed your account was newly added or updated by your domain administrator. Please use the temporary password below to sign in to console and reset it. {{temp_password}}
Login to Console
Sincerely yours, {{service_name}}
Homepage | Blog | Help Center Copyright 2023 © MEGAZONE CLOUD Corp. All Right Reserved.